==> google-cloud-tasks-2.1.0.tar.gz: google-cloud-tasks-2.1.0/google/cloud/tasks_v2beta3/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .target import (
    HttpRequest,
    AppEngineHttpQueue,
    AppEngineHttpRequest,
    AppEngineRouting,
    OAuthToken,
    OidcToken,
)
from .queue import (
    Queue,
    RateLimits,
    RetryConfig,
    StackdriverLoggingConfig,
)
from .task import (
    Task,
    Attempt,
)
from .cloudtasks import (
    ListQueuesRequest,
    ListQueuesResponse,
    GetQueueRequest,
    CreateQueueRequest,
    UpdateQueueRequest,
    DeleteQueueRequest,
    PurgeQueueRequest,
    PauseQueueRequest,
    ResumeQueueRequest,
    ListTasksRequest,
    ListTasksResponse,
    GetTaskRequest,
    CreateTaskRequest,
    DeleteTaskRequest,
    RunTaskRequest,
)


__all__ = (
    "HttpRequest",
    "AppEngineHttpQueue",
    "AppEngineHttpRequest",
    "AppEngineRouting",
    "OAuthToken",
    "OidcToken",
    "Queue",
    "RateLimits",
    "RetryConfig",
    "StackdriverLoggingConfig",
    "Task",
    "Attempt",
    "ListQueuesRequest",
    "ListQueuesResponse",
    "GetQueueRequest",
    "CreateQueueRequest",
    "UpdateQueueRequest",
    "DeleteQueueRequest",
    "PurgeQueueRequest",
    "PauseQueueRequest",
    "ResumeQueueRequest",
    "ListTasksRequest",
    "ListTasksResponse",
    "GetTaskRequest",
    "CreateTaskRequest",
    "DeleteTaskRequest",
    "RunTaskRequest",
)

==> google-cloud-tasks-2.10.2.tar.gz: google-cloud-tasks-2.10.2/google/cloud/tasks_v2beta3/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .cloudtasks import (
    CreateQueueRequest,
    CreateTaskRequest,
    DeleteQueueRequest,
    DeleteTaskRequest,
    GetQueueRequest,
    GetTaskRequest,
    ListQueuesRequest,
    ListQueuesResponse,
    ListTasksRequest,
    ListTasksResponse,
    PauseQueueRequest,
    PurgeQueueRequest,
    ResumeQueueRequest,
    RunTaskRequest,
    UpdateQueueRequest,
)
from .queue import Queue, QueueStats, RateLimits, RetryConfig, StackdriverLoggingConfig
from .target import (
    AppEngineHttpQueue,
    AppEngineHttpRequest,
    AppEngineRouting,
    HttpMethod,
    HttpRequest,
    OAuthToken,
    OidcToken,
    PullMessage,
)
from .task import Attempt, Task

__all__ = (
    "CreateQueueRequest",
    "CreateTaskRequest",
    "DeleteQueueRequest",
    "DeleteTaskRequest",
    "GetQueueRequest",
    "GetTaskRequest",
    "ListQueuesRequest",
    "ListQueuesResponse",
    "ListTasksRequest",
    "ListTasksResponse",
    "PauseQueueRequest",
    "PurgeQueueRequest",
    "ResumeQueueRequest",
    "RunTaskRequest",
    "UpdateQueueRequest",
    "Queue",
    "QueueStats",
    "RateLimits",
    "RetryConfig",
    "StackdriverLoggingConfig",
    "AppEngineHttpQueue",
    "AppEngineHttpRequest",
    "AppEngineRouting",
    "HttpRequest",
    "OAuthToken",
    "OidcToken",
    "PullMessage",
    "HttpMethod",
    "Attempt",
    "Task",
)
